<?php
// Set SEO title, meta description, and meta keywords
$seoTitle = 'About Us | LogoA2Z';
$metaDescription = 'Discover LogoA2Z, the leading source for high-quality brand logos in various formats such as HD PNG, SVG, editable AI, and ZIP files.';
$metaKeywords = 'About Us, Logo Download, HD PNG Logo, SVG Logo, AI Logo, ZIP Logo';

// Sanitize output to prevent XSS attacks
$seoTitle = htmlspecialchars($seoTitle, ENT_QUOTES, 'UTF-8');
$metaDescription = htmlspecialchars($metaDescription, ENT_QUOTES, 'UTF-8');
$metaKeywords = htmlspecialchars($metaKeywords, ENT_QUOTES, 'UTF-8');

include 'header.php'; // Include header.php from the main directory
?>

<link rel="stylesheet" href="/styles.css"> <!-- Assuming styles.css is in the main directory -->

<div class="container">
    <div class="content-box">
        <!-- Main Title -->
        <h1><?php echo $seoTitle; ?></h1>

        <!-- About Us Content -->
        <section class="about-us">
            <p>Welcome to LogoA2Z, your ultimate destination for a vast range of high-quality brand logos. We offer an extensive collection of logos, from A to Z, in various formats including HD PNG, SVG, editable AI, and ZIP bundles. Whether you're working on a design project, branding for a new business, or simply need a logo for your website, we have everything you're looking for.</p>
            
            <p>With our easy-to-use platform, you can download logos in your preferred file format, ensuring that you have the right files for any purpose—whether digital or print. Explore our collection and find logos from top brands, available in a variety of sizes and formats.</p>

            <h2>Why Choose LogoA2Z?</h2>
            <ul>
                <li>Extensive library of logos, from A to Z, covering all industries and sectors.</li>
                <li>High-quality files in multiple formats including PNG, SVG, AI, and ZIP for maximum flexibility.</li>
                <li>Easy-to-use website with fast and secure logo downloads.</li>
                <li>Download individual logos or get the entire collection in one ZIP file for convenience.</li>
            </ul>

            <p>At LogoA2Z, we're committed to providing the best logos in the highest quality formats, ensuring that you always have the right tools to build your brand or project. Start exploring our collection today!</p>
        </section>
    </div>
</div>

<style>
    /* About Us Section */
    .about-us {
        font-size: 1.1em;
        line-height: 1.8;
        margin-top: 20px;
    }

    .about-us p {
        margin-bottom: 20px;
        color: #555;
    }

    .about-us h2, .about-us h3 {
        color: #222;
        font-weight: 600;
        margin-top: 30px;
        margin-bottom: 10px;
    }

    /* Download Section */
    .download-section {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
        gap: 20px;
        margin-top: 20px;
    }

    .download-option {
        background: #fff;
        border: 1px solid #ddd;
        border-radius: 8px;
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        padding: 20px;
        text-align: center;
        transition: transform 0.3s, box-shadow 0.3s;
    }

    .download-option:hover {
        transform: translateY(-5px);
        box-shadow: 0 6px 15px rgba(0, 0, 0, 0.2);
    }

    .download-option h3 {
        font-size: 1.3em;
        color: #333;
    }

    .download-option p {
        margin-bottom: 15px;
        font-size: 0.95em;
        color: #777;
    }

    /* Download Buttons */
    .download-button {
        display: inline-block;
        padding: 12px 20px;
        background-color: #e31b23; /* Brand color */
        color: #fff;
        text-decoration: none;
        border-radius: 5px;
        font-size: 1em;
        transition: background-color 0.3s, box-shadow 0.3s;
        text-align: center;
        width: 200px;
        height: 50px;
        line-height: 50px;
    }

    .download-button:hover {
        background-color: #c7151f; /* Darker shade on hover */
        box-shadow: 0 6px 10px rgba(0, 0, 0, 0.1);
    }

    /* Responsive Styles */
    @media (max-width: 768px) {
        .download-section {
            grid-template-columns: 1fr; /* Stack items on smaller screens */
        }

        .download-button {
            width: 100%; /* Full-width buttons on smaller screens */
        }
    }
</style>

<?php include 'footer.php'; // Include footer.php from the main directory ?>
