<?php
session_start();

// Define the base directory where logo posts are stored
$baseDir = $_SERVER['DOCUMENT_ROOT'] . '/car-logo'; // Path to store logos (in root directory)

if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: login.php'); // Redirect to login page if not logged in
    exit;
}

// Handle form submission and create the brand file
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $brandName = $_POST['brand_name'];
    $slug = strtolower(str_replace(' ', '-', $brandName)); // Generate slug for the brand
    $companyDetails = $_POST['company_details']; // Company details (year, website, etc.)
    $tabs = $_POST['tabs']; // Tabs data (year, content, and file uploads)
    $colorSwatches = $_POST['color_swatches']; // Color swatches
    $companyOverview = $_POST['company_overview']; // Company overview (rich text)
    $featuredImage = $_FILES['featured_image']; // Featured image upload

    // Create the directory for the brand page
    $brandFilePath = $baseDir . '/' . $slug . '.php';
    $fileContent = "<?php\n";
    $fileContent .= "// Include header (public-facing header)\n";
    $fileContent .= "include \$_SERVER['DOCUMENT_ROOT'] . '/header.php';\n";
    $fileContent .= "?>\n\n";

    // HTML structure starts here
    $fileContent .= "<!DOCTYPE html>\n<html lang='en'>\n<head>\n";
    $fileContent .= "<meta charset='UTF-8'>\n";
    $fileContent .= "<meta name='viewport' content='width=device-width, initial-scale=1.0'>\n";
    $fileContent .= "<meta name='keywords' content='{$brandName} Logo, Car Brands, {$brandName} Motor'>\n";
    $fileContent .= "<meta name='description' content='Explore the evolution of the {$brandName} logo from its earliest version to the latest. Learn about the design history and features of the {$brandName} logo.'>\n";
    $fileContent .= "<meta name='author' content='{$brandName} Motor'>\n";
    $fileContent .= "<title>{$brandName} Logo - Car Brands Logos</title>\n";
    $fileContent .= "<link rel='stylesheet' href='/style.css'> <!-- Link to public-facing CSS -->\n";
    $fileContent .= "<link rel='icon' href='/favicon.ico' type='image/x-icon'>\n</head>\n<body>\n";

    $fileContent .= "<div class='container'>\n";
    $fileContent .= "<div class='content-area'>\n";
    $fileContent .= "<h1 class='page-title'>{$brandName} Logo</h1>\n";

    // Company Overview Section
    if (!empty($companyOverview)) {
        $fileContent .= "<section class='company-overview'>\n";
        $fileContent .= "<h2 class='section-title'>Company Overview</h2>\n";
        $fileContent .= "<p>{$companyOverview}</p>\n";
        $fileContent .= "</section>\n";
    }

    // Company Details Section
    $fileContent .= "<div class='company-details'>\n";
    $fileContent .= "<h2 class='section-title'>Company Details</h2>\n";
    $fileContent .= "<table>\n";
    foreach ($companyDetails as $key => $value) {
        $fileContent .= "<tr><td><strong>{$key}:</strong></td><td>{$value}</td></tr>\n";
    }
    $fileContent .= "</table>\n";
    $fileContent .= "</div>\n";

    // Color Swatches Section
    if (!empty($colorSwatches)) {
        $fileContent .= "<h3>Color Swatches</h3>\n";
        foreach ($colorSwatches as $color) {
            $fileContent .= "<div class='color-box' style='background-color: {$color};'></div>\n";
        }
    }

    // Tabs Section (History)
    if (!empty($tabs)) {
        $fileContent .= "<h3>History</h3>\n";
        $fileContent .= "<div class='tab'>\n";
        foreach ($tabs as $tab) {
            $fileContent .= "<div class='tab'>\n";
            $fileContent .= "<h4>{$tab['year']}</h4>\n";
            $fileContent .= "<p>{$tab['content']}</p>\n";
            
            // Add the PNG and SVG logo uploads if they exist
            if (!empty($tab['png_logo']) && !empty($tab['svg_logo'])) {
                $fileContent .= "<p><a href='{$tab['png_logo']}' download>Download PNG Logo</a></p>\n";
                $fileContent .= "<p><a href='{$tab['svg_logo']}' download>Download SVG Logo</a></p>\n";
            }
            $fileContent .= "</div>\n";
        }
        $fileContent .= "</div>\n";
    }

    // Featured Image Section
    if ($featuredImage['error'] == 0) {
        $targetDir = $_SERVER['DOCUMENT_ROOT'] . "/uploads/";
        $targetFile = $targetDir . basename($featuredImage['name']);
        if (move_uploaded_file($featuredImage['tmp_name'], $targetFile)) {
            $fileContent .= "<img src='/uploads/" . basename($featuredImage['name']) . "' alt='Featured Image' />\n";
        }
    }

    // Closing HTML structure
    $fileContent .= "</div>\n</div>\n<?php include \$_SERVER['DOCUMENT_ROOT'] . '/footer.php'; ?>\n";
    $fileContent .= "</body>\n</html>";

    // Write the content to the PHP file
    file_put_contents($brandFilePath, $fileContent);

    echo "Brand page for '{$brandName}' has been created successfully! <br><a href='/car-logo/{$slug}.php'>View the brand page</a>";
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Create New Brand - Admin Panel</title>
    <link rel="stylesheet" href="/admin/styles.css">
    <script src="https://cdn.ckeditor.com/ckeditor5/32.0.0/classic/ckeditor.js"></script> <!-- CKEditor for rich text -->
    
</head>
<body>

<?php include $_SERVER['DOCUMENT_ROOT'] . '/admin/header.php'; ?>

<div class="container">
    <h1>Create New Brand</h1>

    <!-- Form for Creating Brand -->
    <form method="POST" enctype="multipart/form-data">
        <!-- Brand Name -->
        <div class="form-group">
            <label for="brand_name">Brand Name</label>
            <input type="text" name="brand_name" id="brand_name" required>
        </div>

        <!-- Company Details Table -->
        <h2>Company Details</h2>
        <table id="company_details_table">
            <tr>
                <td>Year Founded</td>
                <td><input type="text" name="company_details[Year Founded]" required></td>
            </tr>
            <tr>
                <td>Official Website</td>
                <td><input type="url" name="company_details[Official Website]" required></td>
            </tr>
            <tr>
                <td>Headquarters</td>
                <td><input type="text" name="company_details[Headquarters]" required></td>
            </tr>
            <tr>
                <td>Founders</td>
                <td><input type="text" name="company_details[Founders]" required></td>
            </tr>
            <tr>
                <td>Parent Company</td>
                <td><input type="text" name="company_details[Parent Company]" required></td>
            </tr>
        </table>

        <!-- Color Swatches -->
        <h3>Color Swatches</h3>
        <div id="color_swatches">
            <div class="color-swatch">
                <input type="color" name="color_swatches[]" value="#ff0000">
                <button type="button" class="add-color-swatch">+</button>
            </div>
        </div>

        <!-- Tabs Section -->
        <h3>History</h3>
        <div id="tabs">
            <div class="tab">
                <label for="year_1">Year</label>
                <input type="text" name="tabs[0][year]" id="year_1" value="2023">
                <label for="content_1">Content</label>
                <textarea name="tabs[0][content]" id="content_1">Enter history content here...</textarea>
                <label for="png_logo_1">Upload PNG Logo</label>
                <input type="file" name="tabs[0][png_logo]" id="png_logo_1" accept=".png">
                <label for="svg_logo_1">Upload SVG Logo</label>
                <input type="file" name="tabs[0][svg_logo]" id="svg_logo_1" accept=".svg">
            </div>
        </div>
        <button type="button" id="add-tab">+ Add Tab</button>

        <!-- Company Overview (Rich Text Editor) -->
        <h3>Company Overview</h3>
        <textarea name="company_overview" id="company_overview"></textarea>

        <!-- Featured Image -->
        <h3>Featured Image</h3>
        <input type="file" name="featured_image" id="featured_image" accept="image/*">

        <!-- Submit Button -->
        <button type="submit">Publish</button>
    </form>
</div>

<script>
    // Adding a new tab
    document.getElementById('add-tab').addEventListener('click', function () {
        let tabCount = document.querySelectorAll('.tab').length + 1;
        let newTab = document.createElement('div');
        newTab.classList.add('tab');
        newTab.innerHTML = ` 
            <label for="year_${tabCount}">Year</label>
            <input type="text" name="tabs[${tabCount - 1}][year]" id="year_${tabCount}">
            <label for="content_${tabCount}">Content</label>
            <textarea name="tabs[${tabCount - 1}][content]" id="content_${tabCount}">Enter history content here...</textarea>
            <label for="png_logo_${tabCount}">Upload PNG Logo</label>
            <input type="file" name="tabs[${tabCount - 1}][png_logo]" id="png_logo_${tabCount}" accept=".png">
            <label for="svg_logo_${tabCount}">Upload SVG Logo</label>
            <input type="file" name="tabs[${tabCount - 1}][svg_logo]" id="svg_logo_${tabCount}" accept=".svg">
        `;
        document.getElementById('tabs').appendChild(newTab);
    });

    // Adding new color swatch
    document.querySelector('#color_swatches').addEventListener('click', function (e) {
        if (e.target && e.target.classList.contains('add-color-swatch')) {
            let newSwatch = document.createElement('div');
            newSwatch.classList.add('color-swatch');
            newSwatch.innerHTML = ` 
                <input type="color" name="color_swatches[]" value="#ff0000">
                <button type="button" class="add-color-swatch">+</button>
            `;
            document.getElementById('color_swatches').appendChild(newSwatch);
        }
    });

    // CKEditor for Company Overview
    ClassicEditor
        .create(document.querySelector('#company_overview'))
        .catch(error => {
            console.error(error);
        });
</script>

<?php include $_SERVER['DOCUMENT_ROOT'] . '/admin/footer.php'; ?>

</body>
</html>
