<?php
session_start();

// Define the base directory where logo posts are stored
$baseDir = $_SERVER['DOCUMENT_ROOT'] . '/car-logo'; // Path to store logos (in root directory)

if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: login.php'); // Redirect to login page if not logged in
    exit;
}

// Handle file and post deletions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Delete a specific post
    if (isset($_POST['delete_post'])) {
        $slug = $_POST['slug'];
        $postDir = $baseDir . '/' . $slug;

        // Ensure the post exists and delete the directory
        if (is_dir($postDir)) {
            // Delete all files in the directory
            $files = array_diff(scandir($postDir), ['.', '..']); // Get all files in the directory
            foreach ($files as $file) {
                unlink($postDir . '/' . $file); // Delete each file
            }
            rmdir($postDir); // Remove the empty directory
            echo "<p class='success'>Post '$slug' has been deleted.</p>";
        } else {
            echo "<p class='error'>Post '$slug' not found.</p>";
        }
    }
}

// Get all posts (directories) in the base directory
$posts = array_filter(scandir($baseDir), function ($item) use ($baseDir) {
    return is_dir($baseDir . '/' . $item) && !in_array($item, ['.', '..']); // Fetch only directories
});
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Panel - Manage Logo Posts</title>
    <link rel="stylesheet" href="/admin/styles.css"> <!-- Adjusted to your CSS path -->
    <style>
        .success {
            color: green;
        }
        .error {
            color: red;
        }
        table {
            width: 100%;
            border-collapse: collapse;
        }
        table th, table td {
            padding: 8px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }
        button, .action-links a {
            color: #fff;
            background-color: #d9534f;
            padding: 5px 10px;
            text-decoration: none;
            border: none;
            cursor: pointer;
            border-radius: 5px;
        }
        button:hover, .action-links a:hover {
            background-color: #c9302c;
        }
        .action-links {
            display: inline-block;
        }
        .action-links form {
            display: inline;
        }
    </style>
</head>
<body>

<?php include $_SERVER['DOCUMENT_ROOT'] . '/admin/header.php'; ?>

<div class="container">
    <h1>Admin Panel - Manage Logo Posts</h1>

    <!-- Create New Brand Button -->
    <form method="GET" action="create.php" style="margin-bottom: 20px;">
        <button type="submit">Create New Brand Page</button>
    </form>

    <!-- Display Posts -->
    <h2>Existing Posts</h2>
    <table>
        <thead>
            <tr>
                <th>Brand Name</th>
                <th>Actions</th>
            </tr>
        </thead>
        <tbody>
            <?php if (empty($posts)): ?>
                <tr><td colspan="2">No posts found.</td></tr>
            <?php else: ?>
                <?php foreach ($posts as $post): ?>
                    <tr>
                        <td>
                            <a href="/car-logo/<?php echo urlencode($post); ?>" target="_blank">
                                <?php echo htmlspecialchars($post, ENT_QUOTES, 'UTF-8'); ?>
                            </a>
                        </td>
                        <td class="action-links">
                            <a href="edit.php?slug=<?php echo urlencode($post); ?>">Edit</a> | 
                            <form action="index.php" method="POST" style="display:inline;">
                                <input type="hidden" name="slug" value="<?php echo htmlspecialchars($post, ENT_QUOTES, 'UTF-8'); ?>">
                                <button type="submit" name="delete_post" onclick="return confirm('Are you sure you want to delete this post?')">Delete</button>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<?php include $_SERVER['DOCUMENT_ROOT'] . '/admin/footer.php'; ?>

</body>
</html>
