<!-- Color Swatches Section -->
<?php
// Define watermark colors that should not be displayed
$watermark_colors = ['#606060', '#F84D10', '#444']; // Exclude watermark colors

// Assuming $colors is the array of colors extracted from the SVG
// Filter out the watermark colors
$colors = array_filter($colors, function($color) use ($watermark_colors) {
    return !in_array(strtoupper($color), array_map('strtoupper', $watermark_colors));
});

// Limit to a maximum of 6 swatches
$colors = array_slice($colors, 0, 6);

// Check if the black color is available in the SVG, only then add it to the swatches
if (in_array('#000000', $colors)) {
    $showBlackSwatch = true;
} else {
    $showBlackSwatch = false;
}

// Check if gradients exist and add them as a single swatch
$gradientSwatch = null;
if (isset($gradient)) {
    // If gradients exist, we'll show them as a single swatch
    $gradientSwatch = [
        'type' => 'gradient',
        'colors' => $gradient,  // Assuming $gradient is an array or string representing the gradient
    ];
}

if (empty($colors) && !$gradientSwatch) {
    // If no colors or gradients are available, use a default black swatch
    $colors = ['#000000'];
}
?>

<!-- Show Swatches -->
<div class="color-swatches">
    <h2>Brand Colors for <?= htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8') ?> Logo</h2> <!-- Dynamic heading styled as h2 -->

    <p>Click on the color swatches to copy the color code!</p> <!-- Paragraph with instructions -->

    <!-- Show Gradient Swatch if available -->
    <?php if ($gradientSwatch): ?>
        <div class="swatch gradient-swatch" 
            style="background: <?php echo htmlspecialchars($gradientSwatch['colors'], ENT_QUOTES, 'UTF-8'); ?>;" 
            title="Gradient" 
            onclick="copyColorToClipboard('<?php echo htmlspecialchars($gradientSwatch['colors'], ENT_QUOTES, 'UTF-8'); ?>', this)">
            <span class="tick-mark" style="display: none;">✓</span>
            <div class="overlay"></div> <!-- Dark overlay for clicked swatch -->
        </div>
    <?php endif; ?>

    <!-- Conditionally Show Black Swatch if available -->
    <?php if ($showBlackSwatch): ?>
        <div class="swatch" 
            style="background-color: #000000;" 
            title="#000000" 
            onclick="copyColorToClipboard('#000000', this)">
            <span class="tick-mark" style="display: none;">✓</span>
            <div class="overlay"></div> <!-- Dark overlay for clicked swatch -->
        </div>
    <?php endif; ?>

    <!-- Loop through the colors to create color swatches -->
    <?php foreach ($colors as $color): ?>
        <div class="swatch" 
            style="background-color: <?php echo htmlspecialchars($color, ENT_QUOTES, 'UTF-8'); ?>;" 
            title="<?php echo htmlspecialchars($color, ENT_QUOTES, 'UTF-8'); ?>" 
            onclick="copyColorToClipboard('<?php echo htmlspecialchars($color, ENT_QUOTES, 'UTF-8'); ?>', this)">
            <!-- Tick mark to indicate the color was copied -->
            <span class="tick-mark" style="display: none;">✓</span>
            <div class="overlay"></div> <!-- Dark overlay for clicked swatch -->
        </div>
    <?php endforeach; ?>
</div>

<script>
// Function to copy color hex to clipboard and show tick mark on swatch
function copyColorToClipboard(color, swatchElement) {
    // Create a temporary input element to copy the color
    var tempInput = document.createElement('input');
    tempInput.value = color;
    document.body.appendChild(tempInput);
    tempInput.select();
    document.execCommand('copy');
    document.body.removeChild(tempInput);

    // Show a tick mark on the swatch element to indicate success
    var tickMark = swatchElement.querySelector('.tick-mark');
    var overlay = swatchElement.querySelector('.overlay');

    // Apply dark overlay when swatch is clicked
    overlay.style.display = 'block';
    tickMark.style.display = 'block';

    // Hide the tick mark and overlay after a short delay
    setTimeout(function() {
        tickMark.style.display = 'none';
        overlay.style.display = 'none';
    }, 1000); // Hide after 1 second
}
</script>

<style>
    
    .color-swatches h2 {
        font-size: 24px; /* Ensures the heading uses global h2 styling */
        color: #333; /* Example color for heading */
    }

    .swatch {
        display: inline-block;
        width: 40px;  /* Reverted back to the previous size */
        height: 40px;
        margin: 5px;
        border: 1px solid #ccc; /* Optional: border around swatches */
        position: relative;
        cursor: pointer;
        overflow: hidden;
    }

    .gradient-swatch {
        background: linear-gradient(to right, #f06, #ffba00); /* Example gradient */
    }

    .tick-mark {
        display: none;
        position: absolute;
        top: 50%;
        left: 50%;
        transform: translate(-50%, -50%);
        color: white;
        font-size: 20px;
        z-index: 10;
        text-shadow: 0 0 3px rgba(0, 0, 0, 0.5);
    }

    .overlay {
        display: none;
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 5;
    }
</style>
