<?php
// Initialize variables for form processing
$successMessage = '';
$errorMessage = '';

// Check if the form is submitted
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Sanitize the input to prevent XSS
    $name = htmlspecialchars(trim($_POST['name']));
    $email = htmlspecialchars(trim($_POST['email']));
    $message = htmlspecialchars(trim($_POST['message']));
    $logo_url = htmlspecialchars(trim($_POST['logo_url']));

    // Validate that the URL contains "logoa2z.com"
    if (strpos($logo_url, 'logoa2z.com') === false) {
        $errorMessage = "Invalid logo URL. Please make sure the URL contains 'logoa2z.com'.";
    } else {
        // Prepare the content to save
        $content = "Name: $name\nEmail: $email\nLogo URL: $logo_url\nMessage: $message\n\n";
        
        // Specify the path to your text file
        $filePath = 'webmails.txt';
        
        // Append the content to the file
        if (file_put_contents($filePath, $content, FILE_APPEND | LOCK_EX)) {
            $successMessage = "Thank you for your message! We will get back to you shortly.";
        } else {
            $errorMessage = "There was an error saving your message. Please try again.";
        }
    }
}

// Set SEO title, meta description, and meta keywords
$seoTitle = 'Contact Us | LogoA2Z';
$metaDescription = 'Get in touch with LogoA2Z for any inquiries or support. Reach out to us via email or the form below.';
$metaKeywords = 'Contact Us, Support, Inquiries, Email';

include 'header.php'; // Include header.php from the main directory
?>

<link rel="stylesheet" href="/styles.css"> <!-- Assuming styles.css is in the main directory -->

<div class="container contact-page">
    <h1 class="contact-page-title"><?php echo $seoTitle; ?></h1>

    <section class="contact-content">
        <p class="contact-description">Have a question, or need to report a logo? We’re here to help! Fill out the form below or email us directly.</p>

        <h2 class="contact-form-title">Contact Form</h2>
        
        <form method="post" class="contact-form">
            <!-- Logo URL Field -->
            <div class="form-group">
                <label for="logo_url">Logo URL:</label>
                <input type="url" id="logo_url" name="logo_url" placeholder="https://logoa2z.com/logos/google" value="<?php echo isset($_GET['logo_url']) ? $_GET['logo_url'] : ''; ?>" required>
            </div>

            <!-- Name Field -->
            <div class="form-group">
                <label for="name">Your Name:</label>
                <input type="text" id="name" name="name" required>
            </div>

            <!-- Email Field -->
            <div class="form-group">
                <label for="email">Your Email:</label>
                <input type="email" id="email" name="email" required>
            </div>

            <!-- Message Field -->
            <div class="form-group">
                <label for="message">Your Message:</label>
                <textarea id="message" name="message" rows="5" required></textarea>
            </div>

            <button type="submit" class="submit-button">Send Message</button>
        </form>

        <?php if ($successMessage): ?>
            <div class="success-message"><?php echo $successMessage; ?></div>
        <?php elseif ($errorMessage): ?>
            <div class="error-message"><?php echo $errorMessage; ?></div>
        <?php endif; ?>
    </section>
</div>

<style>
    /* General Styles */
    body {
        font-family: 'Roboto', sans-serif;
        background-color: #f9f9f9;
        margin: 0;
        padding: 0;
        color: #333;
    }

    .contact-page {
        max-width: 800px;
        margin: 40px auto;
        padding: 20px;
        background-color: white;
        box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
        border-radius: 8px;
    }

    .contact-page-title {
        text-align: center;
        color: #333;
        font-size: 32px;
        margin-bottom: 10px;
    }

    .contact-description {
        text-align: center;
        font-size: 18px;
        color: #555;
        margin-bottom: 20px;
    }

    .contact-form-title {
        font-size: 24px;
        font-weight: bold;
        margin-bottom: 20px;
    }

    /* Contact Form */
    .contact-form {
        display: flex;
        flex-direction: column;
        gap: 20px;
    }

    .form-group {
        display: flex;
        flex-direction: column;
    }

    .form-group label {
        font-weight: 600;
        margin-bottom: 5px;
        color: #333;
    }

    .form-group input,
    .form-group textarea {
        padding: 12px;
        font-size: 16px;
        border: 1px solid #ddd;
        border-radius: 8px;
        margin-top: 5px;
    }

    .form-group input[type="url"] {
        background-color: #f0f0f0;
    }

    .form-group input:focus,
    .form-group textarea:focus {
        outline: none;
        border-color: #0056b3;
        box-shadow: 0 0 5px rgba(0, 86, 179, 0.2);
    }

    .submit-button {
        background-color: #0056b3;
        color: white;
        padding: 15px 25px;
        font-size: 18px;
        border: none;
        border-radius: 8px;
        cursor: pointer;
        transition: background-color 0.3s ease;
    }

    .submit-button:hover {
        background-color: #00408e;
    }

    .success-message,
    .error-message {
        padding: 15px;
        font-size: 16px;
        margin-top: 20px;
        border-radius: 5px;
        color: #fff;
        font-weight: bold;
        text-align: center;
    }

    .success-message {
        background-color: #28a745;
    }

    .error-message {
        background-color: #dc3545;
    }
</style>

<?php include 'footer.php'; ?>
