<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Ensure that the necessary parameters are passed
if (isset($_GET['url']) && isset($_GET['filename'])) {
    $url = $_GET['url']; // Get the URL parameter
    $filename = $_GET['filename']; // Get the filename parameter
} else {
    http_response_code(400); // Bad request
    echo 'Invalid request. URL or filename not provided.';
    exit;
}

// Sanitize and validate the URL and filename to prevent security issues
$url = filter_var($url, FILTER_SANITIZE_URL);
$filename = basename($filename); // Get only the filename without path info

// Construct the full path to the requested file
$fullFilePath = $_SERVER['DOCUMENT_ROOT'] . $url; // Full file path on the server

// Validate if the file exists
if (!file_exists($fullFilePath)) {
    http_response_code(404); // File not found
    echo 'File not found.';
    exit;
}

// Set the correct MIME type based on the file extension
$fileExtension = strtolower(pathinfo($filename, PATHINFO_EXTENSION));

switch ($fileExtension) {
    case 'png':
        $contentType = 'image/png';
        break;
    case 'svg':
        $contentType = 'image/svg+xml';
        break;
    case 'zip':
        $contentType = 'application/zip';
        break;
    case 'ai':
        $contentType = 'application/illustrator';
        break;
    default:
        http_response_code(415); // Unsupported media type
        echo 'Unsupported file type.';
        exit;
}

// Set the headers for the file download
header('Content-Description: File Transfer');
header('Content-Type: ' . $contentType);
header('Content-Disposition: attachment; filename="' . $filename . '"');
header('Content-Length: ' . filesize($fullFilePath));
header('Pragma: public');
header('Cache-Control: public, must-revalidate, post-check=0, pre-check=0');
header('Expires: 0');

// Clean the output buffer
ob_clean();
flush();

// Read and output the file to the browser
readfile($fullFilePath);
exit;
?>
