<?php
/*
Template Name: Logo Download Handler
*/

// Get URL parameters: logo name and download type (e.g., png, svg, ai, zip)
$logo_name = isset($_GET['logo_name']) ? $_GET['logo_name'] : ''; 
$downloadType = isset($_GET['download_type']) ? $_GET['download_type'] : '';

// Ensure download type is one of the allowed options
if (!in_array($downloadType, ['png', 'svg', 'ai', 'zip'])) {
    echo 'Error: Invalid download type.';
    exit;
}

// Function to get the correct file path for each logo type
function getFilePath($logoName, $fileType) {
    // Path to your logos directory
    $baseDir = __DIR__ . '/logos'; // Adjust this path as needed
    $logoDir = $baseDir . '/' . $logoName;

    if (!is_dir($logoDir)) {
        return ''; // Logo directory not found
    }

    // Scan the logo directory for files of the given type
    $files = glob($logoDir . '/*.' . $fileType);  // Find any files with the requested extension in the folder

    // If we found any files of the given type, return the first one
    if (!empty($files)) {
        return $files[0]; // Return the first matching file
    }

    return ''; // No matching file found
}

// Determine which file to serve based on the download type
$filePath = getFilePath($logo_name, $downloadType);

if (empty($filePath)) {
    echo 'Error: The requested file was not found.';
    exit;
}

// Serve the file based on the download type
if ($downloadType === 'zip') {
    // ZIP download
    header('Content-Type: application/zip');
    header('Content-Disposition: attachment; filename="' . $logo_name . '-logo.zip"');
    readfile($filePath);
    exit;
}

if (in_array($downloadType, ['png', 'svg', 'ai'])) {
    // Single file download (PNG, SVG, AI)
    $contentType = '';
    $extension = strtolower($downloadType);

    if ($extension === 'png') {
        $contentType = 'image/png';
    } elseif ($extension === 'svg') {
        $contentType = 'image/svg+xml';
    } elseif ($extension === 'ai') {
        $contentType = 'application/postscript';
    }

    if ($contentType) {
        // Send headers for the selected file type
        header('Content-Type: ' . $contentType);
        header('Content-Disposition: attachment; filename="' . $logo_name . '.' . $extension . '"');
        readfile($filePath);
        exit;
    }
}

echo 'Error: Unsupported download type.';
exit;
?>
