<?php
// index.php

// Define the base directory where logo posts are stored
$baseDir = $_SERVER['DOCUMENT_ROOT'] . '/logos'; // This should point to the 'logos' directory on your server

session_start();

// If the user is not logged in, redirect to login page
if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: login.php'); // Redirect to login page
    exit;
}

// Handle file and post deletions (same as in your original code)
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Delete a specific file
    if (isset($_POST['delete_file'])) {
        $slug = $_POST['slug'];
        $fileName = $_POST['file_name'];
        $filePath = $baseDir . '/' . $slug . '/' . $fileName;
        
        if (file_exists($filePath)) {
            unlink($filePath); // Delete the file
            echo "<p>File '$fileName' has been deleted.</p>";
        } else {
            echo "<p>Error: File not found.</p>";
        }
    }

    // Delete the entire post and its files
    if (isset($_POST['delete_post'])) {
        $slug = $_POST['slug'];
        $postDir = $baseDir . '/' . $slug;

        // Ensure the post exists and delete the directory
        if (is_dir($postDir)) {
            $files = array_diff(scandir($postDir), array('.', '..')); // Get all files in the directory
            foreach ($files as $file) {
                unlink($postDir . '/' . $file); // Delete each file
            }
            rmdir($postDir); // Remove the empty directory
            echo "<p>The post '$slug' and all its files have been deleted.</p>";
        } else {
            echo "<p>Post '$slug' not found.</p>";
        }
    }
}

// Get all posts (directories) in the base directory
$posts = array_filter(scandir($baseDir), function ($item) use ($baseDir) {
    return is_dir($baseDir . '/' . $item) && !in_array($item, ['.', '..']); // Fetch only directories
});

// Handle search functionality
$searchTerm = isset($_GET['search']) ? $_GET['search'] : '';

// If search term is provided, filter posts by the search term
if ($searchTerm !== '') {
    $posts = array_filter($posts, function ($post) use ($searchTerm) {
        return stripos($post, $searchTerm) !== false; // Case-insensitive search
    });
}

// Handle pagination (same as your original code)
$perPage = 50;
$totalPosts = count($posts);
$totalPages = ceil($totalPosts / $perPage);

$currentPage = isset($_GET['page']) ? intval($_GET['page']) : 1;
$offset = ($currentPage - 1) * $perPage;

// Paginate the posts
$postsToShow = array_slice($posts, $offset, $perPage);
?>

<!-- Include Header -->
<?php include 'header.php'; ?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Panel - Manage Logo Posts</title>
    <link rel="stylesheet" href="styles.css"> <!-- This is your main CSS -->
</head>
<body>

    <div class="container">
        <h1>Admin Panel - Manage Logo Posts</h1>

        <!-- Search Bar -->
        <form method="GET" action="" class="search-container">
            <input type="text" name="search" class="search-bar" placeholder="Search for posts..." value="<?php echo htmlspecialchars($searchTerm, ENT_QUOTES, 'UTF-8'); ?>">
            <button type="submit" class="search-button">Search</button>
        </form>

<p style="font-size: 28px;">Total Logos: <?php echo $totalPosts; ?></p>

        <!-- Display Posts -->
        <table>
            <thead>
                <tr>
                    <th>Post Title</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($postsToShow)): ?>
                    <tr><td colspan="2">No posts found.</td></tr>
                <?php else: ?>
                    <?php foreach ($postsToShow as $post): ?>
                        <tr>
                            <td>
                                <a href="/logos/<?php echo urlencode(str_replace(' ', '-', $post)); ?>" class="post-link" target="_blank">
                                    <?php echo htmlspecialchars(str_replace('-', ' ', $post), ENT_QUOTES, 'UTF-8'); ?>
                                </a>
                            </td>
                            <td>
                                <a href="edit.php?edit=<?php echo urlencode($post); ?>">Edit</a> | 
                                <form action="index.php" method="POST" style="display:inline;">
                                    <input type="hidden" name="slug" value="<?php echo htmlspecialchars($post, ENT_QUOTES, 'UTF-8'); ?>">
                                    <button type="submit" name="delete_post" onclick="return confirm('Are you sure you want to delete this entire post?')">Delete Post</button>
                                </form>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>

        <!-- Pagination -->
        <div class="pagination">
            <?php 
            // Include pagination functionality from pagination.php (assuming pagination.php contains the function)
            include 'pagination.php'; 
            // Call the pagination function with required parameters
            echo paginate($totalPages, $currentPage, $searchTerm);
            ?>
        </div>
    </div> <!-- End of .container -->

</body>
</html>
