<?php
// Start the session to handle login logic
session_start();

// Set session timeout to 1 hour (1200 seconds)
$session_timeout = 1200;
if (isset($_SESSION['last_activity']) && (time() - $_SESSION['last_activity'] > $session_timeout)) {
    // If the session has expired, destroy the session
    session_unset(); // Unset all session variables
    session_destroy(); // Destroy the session
}
$_SESSION['last_activity'] = time(); // Update last activity time to current time

// Define the admin credentials (strong password example)
$adminUsername = "logoa2zadmin";
$adminPasswordHash = password_hash("ZeEzaRi@12345", PASSWORD_DEFAULT); // Using password hash for better security

// Handle login form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if the username and password match
    if ($_POST['username'] === $adminUsername && password_verify($_POST['password'], $adminPasswordHash)) {
        $_SESSION['logged_in'] = true;
        header("Location: index.php"); // Redirect to the admin dashboard after login
        exit;
    } else {
        $errorMessage = "Invalid username or password."; // Show error if credentials are incorrect
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Login</title>

    <!-- Favicon -->
    <link rel="icon" href="https://pridelogo.com/assets/favicon.png" type="image/x-icon">
    
    <!-- Google Font (Roboto) -->
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;500&display=swap" rel="stylesheet">

    <!-- Add custom styles for the login page -->
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            background-color: #f0f4f8;
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }

        .login-container {
            background-color: #fff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
            width: 350px;
            text-align: center;
        }

        .login-container img {
            width: 150px;
            margin-bottom: 20px;
        }

        h2 {
            margin-bottom: 20px;
            font-size: 24px;
            color: #333;
        }

        input {
            width: 100%;
            padding: 12px;
            margin: 8px 0;
            border: 1px solid #ddd;
            border-radius: 5px;
            box-sizing: border-box;
            font-size: 16px;
        }

        button {
            width: 100%;
            padding: 12px;
            background-color: #007bff;
            color: #fff;
            border: none;
            border-radius: 5px;
            font-size: 16px;
            cursor: pointer;
            transition: background-color 0.3s;
        }

        button:hover {
            background-color: #0056b3;
        }

        .error-message {
            color: #d9534f;
            margin-top: 10px;
            font-size: 14px;
        }

        .footer {
            margin-top: 20px;
            font-size: 14px;
            color: #888;
        }

    </style>
</head>
<body>

    <div class="login-container">
        <!-- Logo -->
        <img src="https://pridelogo.com/assets/pridelogo.png" alt="Pride Logo">

        <h2>Admin Login</h2>

        <!-- Login Form -->
        <form method="POST" action="login.php">
            <input type="text" name="username" placeholder="Username" required><br>
            <input type="password" name="password" placeholder="Password" required><br>
            <button type="submit">Login</button>
        </form>

        <!-- Display error message if login fails -->
        <?php if (isset($errorMessage)): ?>
            <div class="error-message"><?php echo $errorMessage; ?></div>
        <?php endif; ?>

        <div class="footer">
            <p>Don't have an account? <a href="https://pridelogo.com" style="text-decoration: none; color: #007bff;">Visit Website</a></p>
        </div>
    </div>

</body>
</html>
