<?php
// Set SEO title, meta description, and meta keywords
$seoTitle = 'Privacy Policy | LogoA2Z';
$metaDescription = 'Privacy Policy for LogoA2Z, detailing how we collect, use, and protect your personal information.';
$metaKeywords = 'Privacy Policy, Data Protection, Personal Data, Cookies, User Privacy';

// Sanitize output to prevent XSS attacks
$seoTitle = htmlspecialchars($seoTitle, ENT_QUOTES, 'UTF-8');
$metaDescription = htmlspecialchars($metaDescription, ENT_QUOTES, 'UTF-8');
$metaKeywords = htmlspecialchars($metaKeywords, ENT_QUOTES, 'UTF-8');

include 'header.php'; // Include header.php from the main directory
?>

<link rel="stylesheet" href="/styles.css"> <!-- Assuming styles.css is in the main directory -->

<div class="container">
    <div class="content">
        <!-- Main Title -->
        <h1><?php echo $seoTitle; ?></h1>

        <!-- Privacy Policy Content -->
        <section class="privacy-policy">
            <p class="update-date">Last updated: October 20, 2024</p>
            
            <p>At LogoA2Z, your privacy is of utmost importance to us. This Privacy Policy outlines how we collect, use, and safeguard your personal information when you use our website, services, and interact with us.</p>

            <p>By using our service, you consent to the collection and use of your personal data in accordance with this policy. Please read the following to understand how we manage your data and your rights in relation to your personal information.</p>

            <h2>Information We Collect</h2>
            <p>We may collect and process the following types of personal data:</p>
            <ul>
                <li><strong>Personal Identification Information:</strong> Your name, email address, phone number, etc., when you contact us or sign up for our services.</li>
                <li><strong>Usage Data:</strong> Information about how you use our website, including your IP address, browser type, operating system, and activity on the site.</li>
                <li><strong>Cookies:</strong> Small files that store your preferences to enhance your user experience.</li>
            </ul>

            <h2>How We Use Your Information</h2>
            <p>We use your data for various purposes, including:</p>
            <ul>
                <li>Providing and improving our website and services</li>
                <li>Communicating with you, including responding to inquiries or offering support</li>
                <li>Personalizing your experience on our website</li>
                <li>Understanding website usage trends and improving user experience</li>
            </ul>

            <h2>Cookies</h2>
            <p>Our website uses cookies to collect information and improve your experience. Cookies are small text files that are placed on your device when you visit our website. You can choose to disable cookies in your browser settings, but please note that doing so may affect your ability to use some features of the site.</p>

            <h2>Third-Party Services</h2>
            <p>We do not sell or rent your personal data to third parties. However, we may use third-party services to help operate our website and provide our services. These third-party services may have access to your personal information, but they are obligated to use it solely for the purposes of providing services to us. We ensure that they comply with our privacy standards.</p>

            <h2>Data Security</h2>
            <p>We implement appropriate technical and organizational measures to secure your personal data and protect it from unauthorized access, disclosure, alteration, and destruction. However, no method of internet transmission is 100% secure, so while we strive to protect your personal data, we cannot guarantee absolute security.</p>

            <h2>Your Rights</h2>
            <p>Depending on your location, you may have the following rights in relation to your personal data:</p>
            <ul>
                <li><strong>Right to Access:</strong> You have the right to request access to your personal data.</li>
                <li><strong>Right to Rectification:</strong> You can request that we update or correct your personal data.</li>
                <li><strong>Right to Erasure:</strong> You can request that we delete your personal data, subject to legal obligations.</li>
                <li><strong>Right to Object:</strong> You can object to the processing of your personal data in certain circumstances.</li>
            </ul>

            <h2>Changes to This Privacy Policy</h2>
            <p>We may update this Privacy Policy from time to time. Any changes will be posted on this page, with the updated date clearly mentioned at the top. We encourage you to review this policy periodically for any updates.</p>

            <h2>Contact Us</h2>
            <p>If you have any questions about this Privacy Policy or our data practices, please contact us at:</p>
            <p>Email: <a href="mailto:support@logoa2z.com">support@logoa2z.com</a><br>Phone: +1 (123) 456-7890</p>
        </section>
    </div>
</div>

<style>
    /* General Container Styles */
    .container {
        width: 80%;
        margin: 0 auto;
        padding: 20px;
        color: #555;
    }

    /* Content Styles */
    .content {
        margin-top: 20px;
    }

    /* Main Title */
    h1 {
        font-size: 2.2em;
        margin-bottom: 20px;
        color: #333;
    }

    /* Update Date */
    .update-date {
        font-style: italic;
        margin-bottom: 20px;
        color: #777;
    }

    /* Privacy Policy Section */
    .privacy-policy {
        font-size: 1.1em;
        line-height: 1.8;
    }

    /* Headings */
    h2, h3 {
        border-bottom: 2px solid #ddd; /* Underline for headings */
        padding-bottom: 10px;
        margin-bottom: 20px;
        font-size: 1.5em;
        color: #333;
    }

    h3 {
        font-size: 1.3em;
    }

    ul {
        padding-left: 20px;
        list-style-type: disc;
    }

    ul li {
        margin-bottom: 10px;
    }

    a {
        color: #007bff;
        text-decoration: none;
    }

    a:hover {
        text-decoration: underline;
    }

    /* Responsive Styles */
    @media (max-width: 768px) {
        .container {
            width: 90%;
        }

        h1 {
            font-size: 1.8em;
        }

        h2, h3 {
            font-size: 1.4em;
        }

        .privacy-policy {
            font-size: 1em;
        }
    }
</style>

<?php include 'footer.php'; ?>
