<?php
// Define the base directories
$logosDir = __DIR__ . '/logos'; // Directory for logo folders
$webBaseUrl = '/logos'; // Web-accessible URL

// Get all folders in the logos directory
$folders = array_filter(glob($logosDir . '/*'), 'is_dir');

// Get the current brand name from the slug (assuming you already have this from previous code)
$currentBrandName = basename($foundDir); // Get the current brand name

// Get the first word of the current brand name
$firstWord = strtok($currentBrandName, ' ');

// Filter folders that start with the same first word, excluding the current logo
$relatedFolders = array_filter($folders, function($folder) use ($firstWord, $currentBrandName) {
    return stripos(basename($folder), $firstWord) === 0 && basename($folder) !== $currentBrandName; // Exclude current brand
});

// Shuffle the folders to get a random selection for recent logos
shuffle($folders);
$recentFolders = array_filter($folders, function($folder) use ($currentBrandName) {
    return basename($folder) !== $currentBrandName; // Exclude current brand for recent logos
});

// Prepare the logos to display
$logosToDisplay = [];

// Add related logos (up to 6 total)
if (!empty($relatedFolders)) {
    $relatedLogos = array_slice($relatedFolders, 0, 6); // Get all related logos, up to 6
    $logosToDisplay = array_merge($logosToDisplay, $relatedLogos);
}

// If there are still less than 6 logos, fill in with recent logos
if (count($logosToDisplay) < 6) {
    $logosToDisplay = array_merge($logosToDisplay, array_slice($recentFolders, 0, 6 - count($logosToDisplay)));
}

// Ensure exactly 6 logos are displayed
$logosToDisplay = array_slice($logosToDisplay, 0, 6);

// Output the related posts
if (!empty($logosToDisplay)) {
    echo '<div class="related-posts">';
    echo '<h2>Related Logos</h2>';
    echo '<div class="related-posts-container">';

    foreach ($logosToDisplay as $folder) {
        $brand_name = basename($folder); // Get folder name as brand name
        $pngFiles = glob($folder . '/*.png'); // Get all PNG files in the folder

        // Display the first PNG file found as the logo
        if (!empty($pngFiles)) {
            $thumbnail_url = $webBaseUrl . '/' . $brand_name . '/' . basename($pngFiles[0]); // Build the web URL
            $post_slug = strtolower(trim(str_replace(' ', '-', $brand_name))); // Create slug for the post link
            $post_link = "/logos/$post_slug/"; // Ensure the slug includes /logos/

            echo '<div class="related-post">';
            echo '<a href="' . htmlspecialchars($post_link, ENT_QUOTES, 'UTF-8') . '">';
            echo '<img src="' . htmlspecialchars($thumbnail_url, ENT_QUOTES, 'UTF-8') . '" alt="' . htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8') . ' Logo" title="' . htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8') . ' Logo PNG Vector" class="related-post-thumbnail">';
            echo '<p>' . htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8') . '</p>';
            echo '</a>';
            echo '</div>';
        }
    }

    echo '</div>';
    echo '</div>';
} else {
    echo '<p>No related logos available.</p>';
}
?>
