<?php
// Get the search query from the URL
$query = isset($_GET['query']) ? trim($_GET['query']) : '';

// If no query is provided, return an empty JSON response for AJAX requests
if ($query === '') {
    if (isset($_GET['ajax'])) {
        echo json_encode([]); // Return empty array for AJAX
        exit;
    } else {
        header('Location: /'); // Redirect to homepage if no query
        exit;
    }
}

// Sanitize the search query
$query = strtolower(trim($query));

// Initialize an array to hold the results
$results = [];

// Set the base directory for logos
$baseDir = __DIR__ . '/logos'; // Adjust the server path
$webBaseUrl = '/logos'; // Web-accessible URL
$folders = array_filter(glob($baseDir . '/*'), 'is_dir'); // Get all folders

// Iterate through each folder
foreach ($folders as $folder) {
    $brand_name = basename($folder); // Get folder name as brand name

    // Check if the brand name matches the search query (case-insensitive)
    if (stripos($brand_name, $query) !== false) { // Use stripos for case-insensitive match
        $pngFiles = glob($folder . '/*.png'); // Get all PNG files in the folder

        // Display the first PNG file found as the logo
        if (!empty($pngFiles)) {
            $thumbnail_url = $webBaseUrl . '/' . $brand_name . '/' . basename($pngFiles[0]); // Build the web URL
            $results[] = [
                'name' => htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8'),
                'logo' => htmlspecialchars($thumbnail_url, ENT_QUOTES, 'UTF-8')
            ];
        }
    }
}

// Check if this is an AJAX request and return JSON
if (isset($_GET['ajax'])) {
    header('Content-Type: application/json');
    echo json_encode($results);
    exit;
}

// Standard search page handling (if not an AJAX request)
// Set SEO title, meta description, and keywords for standard search
$seoTitle = 'Search: ' . htmlspecialchars($query, ENT_QUOTES, 'UTF-8') . ' Logo PNG Vector';
$metaDescription = 'Search results for "' . htmlspecialchars($query, ENT_QUOTES, 'UTF-8') . '" on LogoA2Z.';
$metaKeywords = 'search results, ' . htmlspecialchars($query, ENT_QUOTES, 'UTF-8');

include 'header.php'; // Include your header

// Display results in a standard format
?>
<link rel="stylesheet" href="/styles.css"> <!-- Assuming styles.css is in the main directory -->
<div class="container">
    <h1><?php echo $seoTitle; ?></h1>
    <div class="recent-posts">
        <div class="recent-posts-container">
            <?php foreach ($results as $result): ?>
                <div class="recent-post">
                    <a href="/logos/<?php echo strtolower(trim(str_replace(' ', '-', $result['name']))); ?>">
                        <img src="<?php echo $result['logo']; ?>" alt="<?php echo $result['name']; ?> Logo" class="recent-post-thumbnail">
                        <p><?php echo $result['name']; ?></p>
                    </a>
                </div>
            <?php endforeach; ?>
        </div>
    </div>

    <?php if (empty($results)): ?>
        <p>No results found for "<?php echo htmlspecialchars($query, ENT_QUOTES, 'UTF-8'); ?>".</p>
    <?php endif; ?>
</div>

<?php include 'footer.php'; // Include your footer ?>
