<?php
// The Loop to get the post content
get_header();

// Sample car logo details (can be dynamic from the database)
$brand_name = "Tesla";
$brand_summary = "Tesla is an electric vehicle and clean energy company, founded by Elon Musk. The company focuses on sustainability through its electric cars, solar products, and battery technology.";
$brand_colors = "Red, Black, White"; // These could be fetched dynamically
$logo_designer = "Tesla Design Team";
$logo_history = [
    "2023" => ["logo" => "logo2023.png", "details" => "Current Tesla logo. Streamlined modern design.", "svg" => "logo2023.svg"],
    "2021" => ["logo" => "logo2021.png", "details" => "Previous iteration of the Tesla logo.", "svg" => "logo2021.svg"],
    "2019" => ["logo" => "logo2019.png", "details" => "Earlier Tesla logo with sharper edges.", "svg" => "logo2019.svg"]
];

$company_details = [
    "Year Founded" => "2003",
    "Owner" => "Elon Musk",
    "Official Site" => "https://www.tesla.com"
];

// Article Section
$article_heading = "Company Overview";
$article_content = "Tesla, Inc. was founded in 2003 with the aim to revolutionize the automobile industry with electric vehicles. The company is known for its high-performance electric cars, like the Model S, Model 3, and Model X.";

// Related logos widget - this can be dynamically pulled from the database
$related_logos = [
    "BMW" => "bmw_logo.png",
    "Audi" => "audi_logo.png",
    "Nissan" => "nissan_logo.png"
];
?>

<div class="car-logo-details">
    <!-- Post Title -->
    <h1><?php echo $brand_name; ?></h1>

    <!-- Summary Paragraph -->
    <p><?php echo $brand_summary; ?></p>

    <!-- Logo Details Box -->
    <div class="logo-details">
        <h3>Logo Details</h3>
        <p><strong>Designer:</strong> <?php echo $logo_designer; ?></p>
        <p><strong>Brand Colors:</strong> <?php echo $brand_colors; ?></p>
    </div>

    <!-- Logo History / Evolution Tabs -->
    <div class="logo-history">
        <h3>Logo History / Evolution</h3>
        <ul class="tabs">
            <?php foreach ($logo_history as $year => $history): ?>
                <li class="tab-link" data-tab="tab-<?php echo $year; ?>"><?php echo $year; ?></li>
            <?php endforeach; ?>
        </ul>

        <div class="tab-content">
            <?php foreach ($logo_history as $year => $history): ?>
                <div id="tab-<?php echo $year; ?>" class="tab">
                    <img src="images/<?php echo $history['logo']; ?>" alt="Tesla Logo <?php echo $year; ?>">
                    <p><strong>Details:</strong> <?php echo $history['details']; ?></p>
                    <p><a href="downloads/<?php echo $history['svg']; ?>" download>Download SVG</a> | <a href="downloads/<?php echo $history['logo']; ?>" download>Download PNG</a></p>
                </div>
            <?php endforeach; ?>
        </div>
    </div>

    <!-- Company Details Table -->
    <div class="company-details">
        <h3>Company Details</h3>
        <table>
            <tr><td><strong>Year Founded:</strong></td><td><?php echo $company_details['Year Founded']; ?></td></tr>
            <tr><td><strong>Owner:</strong></td><td><?php echo $company_details['Owner']; ?></td></tr>
            <tr><td><strong>Official Site:</strong></td><td><a href="<?php echo $company_details['Official Site']; ?>" target="_blank"><?php echo $company_details['Official Site']; ?></a></td></tr>
        </table>
    </div>

    <!-- Article Section -->
    <div class="company-article">
        <h3><?php echo $article_heading; ?></h3>
        <p><?php echo $article_content; ?></p>
    </div>

    <!-- Related Logos Widget -->
    <div class="related-logos">
        <h3>Related Logos</h3>
        <ul>
            <?php foreach ($related_logos as $brand => $logo): ?>
                <li><img src="images/<?php echo $logo; ?>" alt="<?php echo $brand; ?> Logo"> <?php echo $brand; ?></li>
            <?php endforeach; ?>
        </ul>
    </div>
</div>

<?php get_footer(); ?>
