<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Include the functions file in the main directory
include 'functions.php'; // No need for ../

$seoTitle = 'Thank You for Downloading...';
$metaDescription = 'Thank you for downloading from our site.';
$metaKeywords = 'thank you, download, logo';
addCanonicalTag(); // Ensure this function is defined in functions.php

// Include header
include 'header.php'; // No need for ../

// Ensure that the necessary parameters are passed
if (isset($_GET['url']) && isset($_GET['filename'])) {
    $url = htmlspecialchars($_GET['url']);
    $filename = htmlspecialchars($_GET['filename']);
} else {
    http_response_code(400);
    echo 'Invalid request.';
    exit;
}

// Define the base directories for logos
$logosDir = __DIR__ . '/logos'; // Directory for logo folders
$webBaseUrl = '/logos'; // Web-accessible URL

// Get all folders in the logos directory
$folders = array_filter(glob($logosDir . '/*'), 'is_dir');

// Get the first word of the current brand name
$slug = htmlspecialchars(basename($_SERVER['REQUEST_URI'])); // Get the slug from the URL
$currentBrandName = str_replace('-', ' ', $slug); // Convert slug back to the brand name
$firstWord = strtok($currentBrandName, ' ');

// Filter folders that start with the same first word, excluding the current logo
$relatedFolders = array_filter($folders, function($folder) use ($firstWord, $currentBrandName) {
    return stripos(basename($folder), $firstWord) === 0 && basename($folder) !== $currentBrandName; // Exclude current brand
});

// Shuffle the folders to get a random selection for recent logos
shuffle($folders);
$recentFolders = array_filter($folders, function($folder) use ($currentBrandName) {
    return basename($folder) !== $currentBrandName; // Exclude current brand for recent logos
});

// Prepare the logos to display
$logosToDisplay = [];

// Check if there are any related logos
if (!empty($relatedFolders)) {
    // Add related logos up to 6 total
    $logosToDisplay = array_merge(array_values($relatedFolders), array_slice($recentFolders, 0, 6 - count($relatedFolders)));
} else {
    // If no related logos, take recent logos
    $logosToDisplay = array_slice($recentFolders, 0, 6);
}

// Ensure exactly 6 logos are displayed
$logosToDisplay = array_slice($logosToDisplay, 0, 6);

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="<?= htmlspecialchars($metaDescription) ?>">
    <meta name="keywords" content="<?= htmlspecialchars($metaKeywords) ?>">
    <title><?= htmlspecialchars($seoTitle) ?></title>
    <link rel="stylesheet" href="/styles.css">
    <meta name="robots" content="noindex"> <!-- Prevent indexing of this page -->
    <style>
        .thank-you-container {
            display: flex;
            flex-wrap: wrap; /* Allow items to wrap on smaller screens */
            justify-content: space-between;
            align-items: flex-start; /* Align items to the top */
            margin: 20px 0;
        }
        .thank-you-message, .ad-banner {
            width: 300px; /* Set a fixed width for each column */
            text-align: center;
            margin: 10px; /* Add horizontal spacing */
        }
        .countdown {
            width: 300px; /* Fixed width for the countdown box */
            height: 300px; /* Fixed height for the countdown box */
            font-size: 24px; /* Main text size */
            font-weight: bold;
            color: black; /* Change this to your desired color */
            padding: 15px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1); /* Soft shadow for depth */
            margin-top: 10px; /* Space above to prevent touching */
            display: flex;
            justify-content: center;
            align-items: center;
            flex-direction: column; /* Center the text vertically */
        }
        .countdown span {
            font-size: 48px; /* Make seconds larger */
            color: red; /* Change to a contrasting color for seconds */
        }

        @media (max-width: 600px) {
            .thank-you-container {
                flex-direction: column; /* Stack items on mobile */
                align-items: center; /* Center align items */
            }
            .ad-banner {
                order: -1; /* Make ad banner the first column on mobile */
                width: 100%; /* Ensure it takes full width */
                margin: 10px 0; /* Vertical spacing */
            }
            .thank-you-message {
                width: 100%; /* Take full width on small screens */
                margin: 10px 0; /* Vertical spacing */
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <h1><?= htmlspecialchars($seoTitle) ?></h1>

        <div class="thank-you-container">
            <div class="ad-banner">
                <?php include 'ad.php'; ?> <!-- Include the ad banner -->
            </div>
            <div class="thank-you-message">
                <iframe src="/assets/loading.html" style="width: 100%; height: 300px; border: none;"></iframe> <!-- Logo animation -->
            </div>
            <div class="countdown">
                <h3>Please wait for <span id="timer">3</span> seconds...</h3>
            </div>
        </div>

        <script>
            let countdown = 3; // Countdown timer starting at 3 seconds
            const timerElement = document.getElementById('timer');

            const interval = setInterval(() => {
                countdown--;
                timerElement.textContent = countdown;
                if (countdown <= 0) {
                    clearInterval(interval);
                    const countdownBox = timerElement.parentElement;
                    countdownBox.innerHTML = "<h3 style='color: #00C446;'>Done!</h3>"; // Change text color to lime
                    const messageElement = document.createElement('div');
                    messageElement.textContent = "You've Downloaded Logo Successfully!";
                    messageElement.style.fontSize = "24px"; // Style the success message
                    messageElement.style.fontWeight = "bold"; // Make it bold
                    messageElement.style.color = "#00C446"; // Set text color to lime green
                    messageElement.style.marginTop = "10px"; // Space above
                    countdownBox.appendChild(messageElement); // Append message

                    // Start the download
                    const link = document.createElement('a');
                    link.href = '<?= $url ?>';
                    link.download = '<?= $filename ?>';
                    document.body.appendChild(link);
                    link.click();
                    document.body.removeChild(link);
                }
            }, 1000); // Update every second
        </script>

        <div class="related-posts">
            <h2>Related Logos</h2>
            <div class="related-posts-container">
                <?php
                if (!empty($logosToDisplay)) {
                    foreach ($logosToDisplay as $folder) {
                        $brand_name = basename($folder); // Get folder name as brand name
                        $pngFiles = glob($folder . '/*.png'); // Get all PNG files in the folder

                        // Display the first PNG file found as the logo
                        if (!empty($pngFiles)) {
                            $thumbnail_url = $webBaseUrl . '/' . $brand_name . '/' . basename($pngFiles[0]); // Build the web URL
                            $post_slug = strtolower(trim(str_replace(' ', '-', $brand_name))); // Create slug for the post link
                            $post_link = "/logos/$post_slug/"; // Ensure the slug includes /logos/

                            echo '<div class="related-post">';
                            echo '<a href="' . htmlspecialchars($post_link, ENT_QUOTES, 'UTF-8') . '">';
                            echo '<img src="' . htmlspecialchars($thumbnail_url, ENT_QUOTES, 'UTF-8') . '" alt="' . htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8') . ' Logo" class="related-post-thumbnail">';
                            echo '<p>' . htmlspecialchars($brand_name, ENT_QUOTES, 'UTF-8') . '</p>';
                            echo '</a>';
                            echo '</div>';
                        }
                    }
                } else {
                    echo '<p>No related logos available.</p>';
                }
                ?>
            </div>
        </div>
    </div>
</body>
</html>

<?php include 'footer.php'; ?> <!-- Include footer -->
